==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ApplicationLayoutsLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ApplicationLayoutsLinks
 */
@JsonPropertyOrder({ ApplicationLayoutsLinks.JSON_PROPERTY_GENERAL, ApplicationLayoutsLinks.JSON_PROPERTY_SIGN_ON,
        ApplicationLayoutsLinks.JSON_PROPERTY_PROVISIONING })
@JsonTypeName("ApplicationLayouts__links")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ApplicationLayoutsLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GENERAL = "general";
    private List<HrefObject> general = null;

    public static final String JSON_PROPERTY_SIGN_ON = "signOn";
    private List<HrefObject> signOn = null;

    public static final String JSON_PROPERTY_PROVISIONING = "provisioning";
    private List<HrefObject> provisioning = null;

    public ApplicationLayoutsLinks() {
    }

    public ApplicationLayoutsLinks general(List<HrefObject> general) {

        this.general = general;
        return this;
    }

    public ApplicationLayoutsLinks addgeneralItem(HrefObject generalItem) {
        if (this.general == null) {
            this.general = new ArrayList<>();
        }
        this.general.add(generalItem);
        return this;
    }

    /**
     * Get general
     *
     * @return general
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GENERAL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HrefObject> getGeneral() {
        return general;
    }

    @JsonProperty(JSON_PROPERTY_GENERAL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGeneral(List<HrefObject> general) {
        this.general = general;
    }

    public ApplicationLayoutsLinks signOn(List<HrefObject> signOn) {

        this.signOn = signOn;
        return this;
    }

    public ApplicationLayoutsLinks addsignOnItem(HrefObject signOnItem) {
        if (this.signOn == null) {
            this.signOn = new ArrayList<>();
        }
        this.signOn.add(signOnItem);
        return this;
    }

    /**
     * Get signOn
     *
     * @return signOn
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SIGN_ON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HrefObject> getSignOn() {
        return signOn;
    }

    @JsonProperty(JSON_PROPERTY_SIGN_ON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSignOn(List<HrefObject> signOn) {
        this.signOn = signOn;
    }

    public ApplicationLayoutsLinks provisioning(List<HrefObject> provisioning) {

        this.provisioning = provisioning;
        return this;
    }

    public ApplicationLayoutsLinks addprovisioningItem(HrefObject provisioningItem) {
        if (this.provisioning == null) {
            this.provisioning = new ArrayList<>();
        }
        this.provisioning.add(provisioningItem);
        return this;
    }

    /**
     * Get provisioning
     *
     * @return provisioning
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROVISIONING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HrefObject> getProvisioning() {
        return provisioning;
    }

    @JsonProperty(JSON_PROPERTY_PROVISIONING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProvisioning(List<HrefObject> provisioning) {
        this.provisioning = provisioning;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationLayoutsLinks applicationLayoutsLinks = (ApplicationLayoutsLinks) o;
        return Objects.equals(this.general, applicationLayoutsLinks.general)
                && Objects.equals(this.signOn, applicationLayoutsLinks.signOn)
                && Objects.equals(this.provisioning, applicationLayoutsLinks.provisioning);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(general, signOn, provisioning);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationLayoutsLinks {\n");
        sb.append("    general: ").append(toIndentedString(general)).append("\n");
        sb.append("    signOn: ").append(toIndentedString(signOn)).append("\n");
        sb.append("    provisioning: ").append(toIndentedString(provisioning)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ApplicationLayoutsLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ApplicationLayoutsLinks
 */
@JsonPropertyOrder({ ApplicationLayoutsLinks.JSON_PROPERTY_GENERAL, ApplicationLayoutsLinks.JSON_PROPERTY_SIGN_ON,
        ApplicationLayoutsLinks.JSON_PROPERTY_PROVISIONING })
@JsonTypeName("ApplicationLayouts__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ApplicationLayoutsLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GENERAL = "general";
    private List<HrefObject> general = null;

    public static final String JSON_PROPERTY_SIGN_ON = "signOn";
    private List<HrefObject> signOn = null;

    public static final String JSON_PROPERTY_PROVISIONING = "provisioning";
    private List<HrefObject> provisioning = null;

    public ApplicationLayoutsLinks() {
    }

    public ApplicationLayoutsLinks general(List<HrefObject> general) {

        this.general = general;
        return this;
    }

    public ApplicationLayoutsLinks addgeneralItem(HrefObject generalItem) {
        if (this.general == null) {
            this.general = new ArrayList<>();
        }
        this.general.add(generalItem);
        return this;
    }

    /**
     * Get general
     *
     * @return general
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GENERAL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HrefObject> getGeneral() {
        return general;
    }

    @JsonProperty(JSON_PROPERTY_GENERAL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGeneral(List<HrefObject> general) {
        this.general = general;
    }

    public ApplicationLayoutsLinks signOn(List<HrefObject> signOn) {

        this.signOn = signOn;
        return this;
    }

    public ApplicationLayoutsLinks addsignOnItem(HrefObject signOnItem) {
        if (this.signOn == null) {
            this.signOn = new ArrayList<>();
        }
        this.signOn.add(signOnItem);
        return this;
    }

    /**
     * Get signOn
     *
     * @return signOn
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SIGN_ON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HrefObject> getSignOn() {
        return signOn;
    }

    @JsonProperty(JSON_PROPERTY_SIGN_ON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSignOn(List<HrefObject> signOn) {
        this.signOn = signOn;
    }

    public ApplicationLayoutsLinks provisioning(List<HrefObject> provisioning) {

        this.provisioning = provisioning;
        return this;
    }

    public ApplicationLayoutsLinks addprovisioningItem(HrefObject provisioningItem) {
        if (this.provisioning == null) {
            this.provisioning = new ArrayList<>();
        }
        this.provisioning.add(provisioningItem);
        return this;
    }

    /**
     * Get provisioning
     *
     * @return provisioning
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROVISIONING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HrefObject> getProvisioning() {
        return provisioning;
    }

    @JsonProperty(JSON_PROPERTY_PROVISIONING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProvisioning(List<HrefObject> provisioning) {
        this.provisioning = provisioning;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationLayoutsLinks applicationLayoutsLinks = (ApplicationLayoutsLinks) o;
        return Objects.equals(this.general, applicationLayoutsLinks.general)
                && Objects.equals(this.signOn, applicationLayoutsLinks.signOn)
                && Objects.equals(this.provisioning, applicationLayoutsLinks.provisioning);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(general, signOn, provisioning);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationLayoutsLinks {\n");
        sb.append("    general: ").append(toIndentedString(general)).append("\n");
        sb.append("    signOn: ").append(toIndentedString(signOn)).append("\n");
        sb.append("    provisioning: ").append(toIndentedString(provisioning)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
